@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-$LOAD_PATH.unshift File.dirname(__FILE__)
-require 'helper'
+require_relative 'helper'
 
-class MustacheTest < Test::Unit::TestCase
+class MustacheTest < Minitest::Test
   def test_instance_render
     klass = Class.new(Mustache)
     klass.template = "Hi {{thing}}!"
@@ -15,7 +14,7 @@ end_simple
   end
 
   def test_passenger
-    assert_equal <<-end_passenger, Passenger.to_text
+    assert_equal <<-end_passenger, Passenger.render
 <VirtualHost *>
   ServerName example.com
   DocumentRoot /var/www/example.com
@@ -279,14 +278,19 @@ data
   RailsEnv production
 </VirtualHost>
 data
-    old_path, Mustache.template_path = Mustache.template_path, File.dirname(__FILE__) + "/fixtures"
-    old_extension, Mustache.template_extension = Mustache.template_extension, "conf"
+    old_path = Mustache.template_path
+    old_extension = Mustache.template_extension
 
-    assert_equal expected, Mustache.render(:passenger, :stage => 'production',
-                                                       :server => 'example.com',
-                                                       :deploy_to => '/var/www/example.com' )
+    begin
+      Mustache.template_path = File.dirname(__FILE__) + "/fixtures"
+      Mustache.template_extension = "conf"
 
-    Mustache.template_path, Mustache.template_extension = old_path, old_extension
+      assert_equal expected, Mustache.render(:passenger, :stage => 'production',
+                                                         :server => 'example.com',
+                                                         :deploy_to => '/var/www/example.com')
+    ensure
+      Mustache.template_path, Mustache.template_extension = old_path, old_extension
+    end
   end
 
   def test_doesnt_execute_what_it_doesnt_need_to
@@ -429,7 +433,7 @@ Benvolio is 15
   def test_knows_when_its_been_compiled_when_set_with_string
     klass = Class.new(Mustache)
 
-    assert ! klass.compiled?
+    refute klass.compiled?
     klass.template = 'Hi, {{person}}!'
     assert klass.compiled?
   end
@@ -438,28 +442,29 @@ Benvolio is 15
     klass = Class.new(Simple)
     klass.template_file = File.dirname(__FILE__) + '/fixtures/simple.mustache'
 
-    assert ! klass.compiled?
+    refute klass.compiled?
     klass.render
     assert klass.compiled?
   end
 
   def test_an_instance_knows_when_its_class_is_compiled
-    instance = Simple.new
+    klass = Class.new(Simple)
+    instance = klass.new
 
-    assert ! Simple.compiled?
-    assert ! instance.compiled?
+    refute klass.compiled?, "Simple was already compiled (from class)."
+    refute instance.compiled?, "Simple was already compiled (from instance)."
 
-    Simple.render
+    klass.render
 
-    assert Simple.compiled?
-    assert instance.compiled?
+    assert klass.compiled?, "Simple was not compiled (from class)."
+    assert instance.compiled?, "Simple was not compiled (from instance)."
   end
 
   def test_knows_when_its_been_compiled_at_the_instance_level
     klass = Class.new(Mustache)
     instance = klass.new
 
-    assert ! instance.compiled?
+    refute instance.compiled?
     instance.template = 'Hi, {{person}}!'
     assert instance.compiled?
   end
@@ -739,4 +744,20 @@ FROM
   DUMMY1
 template
   end
+
+  def test_cast_to_hash_in_context
+    hashlike = Object.new
+    def hashlike.title
+      'title'
+    end
+    def hashlike.to_hash
+      { title: 'title' }
+    end
+
+    template = '%%{{title}}%%'
+
+    assert_equal '%%title%%', Mustache.render(template, hashlike)
+
+  end
+
 end
